@@ -7,18 +7,25 @@ Martin Bednar
 import sys
 from PyQt4 import QtGui, QtCore
 a = 0
+warning = "INPUT IS NOT ASCII"
+warning_2 = "PARAPHRASE MUST BE AN INTEGER"
 
+def is_ascii(s):
+    return all(ord(c) < 128 for c in s)
 
 def crypt_me(text,number):
-    len_text = len(text)
-    len_number = len(str(number))
-    output=''
-    str_number = str(number)
-    while(len(str_number)<=len_text):
-        str_number=str_number+str_number
-    for x in xrange(0,len_text):
-        output = output + (chr(ord(text[x])+int(str_number[x])))
-    return output
+    if(is_ascii(text)==False):
+        return "INPUT IS NOT ASCII"
+    else:
+        len_text = len(text)
+        len_number = len(str(number))
+        output=''
+        str_number = str(number)
+        while(len(str_number)<=len_text):
+            str_number=str_number+str_number
+        for x in xrange(0,len_text):
+            output = output + (chr(ord(text[x])+int(str_number[x])))
+        return output
 
 def decrypt_me(text,number):
     len_text = len(text)
@@ -52,13 +59,13 @@ class GUI_Crypt_me(QtGui.QWidget):
         decrypt_button = QtGui.QPushButton("Decrypt_me!",self)
         decrypt_button.setCheckable(True)
 
-        self.paraphrase = QtGui.QLineEdit(self)
+        self.paraphrase = QtGui.QLineEdit("1",self)
 
         label_0 = QtGui.QLabel("Caesar cipher",self)
-        label_1 = QtGui.QLabel("Input text:",self)
+        label_1 = QtGui.QLabel("Input text (ASCII):",self)
         label_2 = QtGui.QLabel("Paraphrase: (should be a number)",self)
         label_3 = QtGui.QLabel("Output text:",self)
-        label_4 = QtGui.QLabel("bo_92 2014",self)
+        label_4 = QtGui.QLabel("bo_92 2014          martin.bednar@hotmail.sk",self)
 
         '''menu_bar = QtGui.QMenuBar(self)
         menu = QtGui.QMenu(self)
@@ -98,11 +105,24 @@ class GUI_Crypt_me(QtGui.QWidget):
     def set_output_text_crypt(self, pressed):
         source = self.sender()
         if(pressed):
-            text = str(self.text_in.toPlainText())
-            paraphrase = str(self.paraphrase.text())
-            crypt = crypt_me(text,paraphrase)
-            self.text_out.clear()
-            self.text_out.append(crypt)
+            global a
+            a=self.text_in
+            try:
+                text = str(self.text_in.toPlainText())
+                paraphrase = str(self.paraphrase.text())
+                crypt = crypt_me(text,paraphrase)
+                self.text_out.clear()
+                self.text_out.append(crypt)
+            except UnicodeEncodeError:
+                self.text_out.clear()
+                global warning
+                self.text_out.append(warning)
+            except ValueError:
+                self.text_out.clear()
+                global warning_2
+                self.text_out.append(warning_2)
+
+
             
 
     def set_output_text_decrypt(self, pressed):
